==> terasoluna-server4jrich-tutorial_2.0.1.0.zip: tutorial-rich/sources/jp/terasoluna/rich/tutorial/service/bean/ResultData.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.rich.tutorial.service.bean;

import java.io.Serializable;
import java.util.List;

/**
 * ʃNX
 *
 */
public class ResultData implements Serializable {
    
    /**
     * VAo[WID
     */
    private static final long serialVersionUID = 7608693713640137329L;
    
    /**
     * [UێBeanB
     */
    private List<UserBean> userBean = null;
     
    /**
     * B
     */
    private Integer totalCount = null;
    
    /**
     * [UێBeanԋpB
     * 
     * @return ێ郆[UێBean
     */
    public List<UserBean> getUserBean() {
        return userBean;
    }
 
    /**
     * [UێBeanݒ肷B
     * 
     * @param userBean [UێBean
     */
    public void setUserBean(List<UserBean> userBean) {
        this.userBean = userBean;
    }
    
    /**
     * ԋpB
     * 
     * @return ێ鑍
     */
    public Integer getTotalCount() {
        return totalCount;
    }

    /**
     * ݒ肷B
     * 
     * @param totalCount 
     */
    public void setTotalCount(Integer totalCount) {
        this.totalCount = totalCount;
    }

}

==> terasoluna-server4jrich-tutorial_2.0.3.0.zip: tutorial-rich/sources/jp/terasoluna/rich/tutorial/service/bean/ResultData.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.terasoluna.rich.tutorial.service.bean;

import java.io.Serializable;
import java.util.List;

/**
 * ʃNX
 *
 */
public class ResultData implements Serializable {

    /**
     * VAo[WIDB
     */
    private static final long serialVersionUID = 1L;
    
    /**
     * [UێBeanXgB
     */
    private List<UserBean> userBean = null;

    /**
     * B
     */
    private Integer totalCount = null;

    /**
     * [UێBeanԋpB
     *
     * @return ێ郆[UێBean
     */
    public List<UserBean> getUserBean() {
        return userBean;
    }

    /**
     * [UێBeanXgݒ肷B
     *
     * @param userBean [UێBeanXg
     */
    public void setUserBean(List<UserBean> userBean) {
        this.userBean = userBean;
    }

    /**
     * [UێBeanXgɒǉB
     *
     * @param userBean [UێBean
     */
    public void addUserBean(UserBean userBean) {
        this.userBean.add(userBean);
    }

    /**
     * ԋpB
     *
     * @return ێ鑍
     */
    public Integer getTotalCount() {
        return totalCount;
    }

    /**
     * ݒ肷B
     *
     * @param totalCount 
     */
    public void setTotalCount(Integer totalCount) {
        this.totalCount = totalCount;
    }
}
